<?php

namespace Drupal\monarch_data_entity\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for the data entity edit forms.
 */
class DataEntityForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $result = parent::save($form, $form_state);

    $entity = $this->getEntity();

    $message_arguments = ['%label' => $entity->toLink()->toString()];
    $logger_arguments = [
      '%label' => $entity->label(),
      'link' => $entity->toLink($this->t('View'))->toString(),
    ];

    switch ($result) {
      case SAVED_NEW:
        $this->messenger()->addStatus($this->t('New data %label has been created.', $message_arguments));
        $this->logger('monarch_data_entity')->notice('Created new data %label', $logger_arguments);
        break;

      case SAVED_UPDATED:
        $this->messenger()->addStatus($this->t('The data %label has been updated.', $message_arguments));
        $this->logger('monarch_data_entity')->notice('Updated data %label.', $logger_arguments);
        break;
    }

    $form_state->setRedirect('entity.data_entity.canonical', ['data_entity' => $entity->id()]);

    return $result;
  }

}
